@@ -1,6 +1,7 @@
 #include "dialogwindow.h"
 #include <QDialog>
 #include <QCloseEvent>
+#include <QKeyEvent>
 
 DialogWindow::DialogWindow(QWidget *parent) :
     QMainWindow(parent)
@@ -8,6 +9,9 @@ DialogWindow::DialogWindow(QWidget *parent) :
     m_Loop = NULL;
     m_CanClose = false;
     m_Result = QDialog::Rejected;
+#ifndef Q_WS_MAEMO_5
+    setWindowModality(Qt::WindowModal);
+#endif
 }
 
 DialogWindow::~DialogWindow()
@@ -18,7 +22,6 @@ DialogWindow::~DialogWindow()
 
 int DialogWindow::exec()
 {
-    setWindowModality(Qt::WindowModal);
     m_Loop = new QEventLoop(this);
     show();
     m_Loop->exec();
@@ -49,3 +52,12 @@ void DialogWindow::closeEvent(QCloseEvent* event)
         event->ignore();
     }
 }
+
+void DialogWindow::keyPressEvent(QKeyEvent * event)
+{
+    if (event->key() == Qt::Key_Escape){
+        close();
+        event->accept();
+    }else
+        event->ignore();
+}
