@@ -6,9 +6,10 @@
 #include <QMessageBox>
 #include <QCloseEvent>
 #include "commonstatic.h"
+#include "combatskillwindow.h"
 
 FightWindow::FightWindow(QWidget *parent, Player* player, Enemy* enemy, bool canEvade, QScriptEngine* engine) :
-    QMainWindow(parent),
+    DialogWindow(parent),
     ui(new Ui::FightWindow)
 {
     ui->setupUi(this);
@@ -30,20 +31,23 @@ FightWindow::FightWindow(QWidget *parent, Player* player, Enemy* enemy, bool can
     ui->lblEnemy->setPalette(secondaryPalette);
 #endif
 
+    ui->lblCombatSkillD->setText("<a href=\"#\">Combat Skill:</a>");
+    connect(ui->lblCombatSkillD, SIGNAL(linkActivated(QString)), this, SLOT(CombatSkillLinkSlot(QString)));
+
+    SetCanClose(false);
     m_UpdatingData = false;
-    m_Close = false;
     m_PlayerPointsLost = 0;
     m_EnemyPointsLost = 0;
     m_Round = 0;
     m_SurpriseRound = 0;
     m_Engine = engine;
-    m_Loop = NULL;
     connect(ui->pbnFight, SIGNAL(clicked()), this, SLOT(AttackSlot()));
     connect(ui->pbnEvade, SIGNAL(clicked()), this, SLOT(EvadeSlot()));
     connect(ui->pbnClose, SIGNAL(clicked()), this, SLOT(Close()));
     connect(ui->cmbDiscipline, SIGNAL(currentIndexChanged(int)), this, SLOT(DisciplineChangedSlot(int)));
 
     m_AttackMultiplier = 1;
+    m_EnemyAttackMultiplier = 1;
     m_AttackBonus = 0;
     m_RandomBonus = 0;
     m_CanEvade = canEvade;
@@ -90,24 +94,6 @@ FightWindow::~FightWindow()
     delete ui;
 }
 
-void FightWindow::exec()
-{
-    m_Loop = new QEventLoop(this);
-    show();
-    m_Loop->exec();
-}
-
-void FightWindow::closeEvent(QCloseEvent* event)
-{
-    if (m_Close){
-        if (m_Loop)
-            m_Loop->quit();
-        event->accept();
-    }else{
-        event->ignore();
-    }
-}
-
 void FightWindow::UpdateData()
 {
     m_UpdatingData = true;
@@ -115,11 +101,11 @@ void FightWindow::UpdateData()
         ui->lblDiscipline->setVisible(true);
         ui->cmbDiscipline->setVisible(true);
 
-        QStringList items;
-        ui->cmbDiscipline->clear();
-        if (!this->m_Enemy->DisciplineImmunities.contains("Mindblast"))
+        QStringList items;        
+        ui->cmbDiscipline->clear();        
+        if (!m_Enemy->DisciplineImmunities.contains("Mindblast"))
             items.append("Mindblast");
-        if (!this->m_Enemy->DisciplineImmunities.contains("Psi-surge"))
+        if (!m_Enemy->DisciplineImmunities.contains("Psi-surge"))
             items.append("Psi-surge");
 
         if (items.count() == 0){
@@ -127,22 +113,23 @@ void FightWindow::UpdateData()
             ui->cmbDiscipline->setCurrentIndex(0);
             ui->cmbDiscipline->setEnabled(false);
         }else{
+            items.insert(0, "None");
+            KaiDiscipline* mindBlast = m_Player->GetDiscipline("Mindblast");
             KaiDiscipline* psiSurge = m_Player->GetDiscipline("Psi-surge");
             if (psiSurge->Active && !items.contains("Psi-surge"))
                 psiSurge->Active = false;
+            if (mindBlast->Active && !items.contains("Mindblast"))
+                mindBlast->Active = false;
 
             if (psiSurge->Active && m_Player->Endurance <= 6){
                 psiSurge->Active = false;
                 ui->cmbDiscipline->setEnabled(false);
             }
 
-            if (items.count() == 1 && items.contains("Psi-surge"))
-                items.insert(0, "None");
-
             ui->cmbDiscipline->addItems(items);
             if (psiSurge->Active)
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("Psi-surge"));
-            else if (items.contains("Mindblast"))
+            else if (mindBlast->Active)
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("Mindblast"));
             else if (items.contains("None"))
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("None"));
@@ -183,8 +170,7 @@ void FightWindow::Close()
 {
     if(!m_Enemy->ExitScript.isEmpty())
         ExecuteScript("ExitScript", m_Enemy->ExitScript);
-    m_Player->TemporaryCombatSkillDelta = 0;
-    m_Close = true;
+    SetCanClose(true);
     close();
 }
 
@@ -269,15 +255,19 @@ void FightWindow::Evaluate(int number)
         if (subele.at(1) == "k")
             m_PlayerDamage = m_Player->Endurance;
         else
-            m_PlayerDamage = subele.at(1).toInt();
+            m_PlayerDamage = subele.at(1).toInt() * m_EnemyAttackMultiplier;
 
         if (m_PlayerDamage > m_Player->Endurance)
             m_PlayerDamage = m_Player->Endurance;
     }
 
     KaiDiscipline* psiSurge = m_Player->GetDiscipline("Psi-surge");
-    if (psiSurge && psiSurge->Active)
-        m_PlayerDamage += 2;
+    if (psiSurge && psiSurge->Active &&m_Player->GetEndurance() >= 6){
+        if (m_Player->GetDisciplineCount() >= 9)
+            m_PlayerDamage += 1;
+        else
+            m_PlayerDamage += 2;
+    }
 
     if(!m_Enemy->DamageScript.isEmpty())
         ExecuteScript("DamageScript", m_Enemy->DamageScript);
@@ -299,7 +289,7 @@ void FightWindow::Evaluate(int number)
             message.append("You were <b>killed</b>");
             ui->lblDice->setText("<font color=\"red\">You lost!</font>");
         }else
-            message.append(QString("You lost <b>%1</b> endurance points").arg(subele.at(1)));
+            message.append(QString("You lost <b>%1</b> endurance points").arg(m_PlayerDamage));
     }
 
     if (m_Player->Endurance < 0)
@@ -399,10 +389,35 @@ void FightWindow::EndFight()
 void FightWindow::DisciplineChangedSlot(int index)
 {
     if (!m_UpdatingData){
-        KaiDiscipline* d = m_Player->GetDiscipline("Psi-surge");
-        if (d){
-            d->Active = ui->cmbDiscipline->itemText(index) == "Psi-surge";
-            UpdateData();
+        QString discipline = ui->cmbDiscipline->itemText(index);
+        if (discipline == "None"){
+            KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
+            if (d)
+                d->Active = false;
+            d = m_Player->GetDiscipline("Psi-surge");
+            if (d)
+                d->Active = false;
+        }else if (discipline == "Mindblast"){
+            KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
+            if (d)
+                d->Active = true;
+            d = m_Player->GetDiscipline("Psi-surge");
+            if (d)
+                d->Active = false;
+        }else if (discipline == "Psi-surge"){
+            KaiDiscipline* d = m_Player->GetDiscipline("Mindblast");
+            if (d)
+                d->Active = false;
+            d = m_Player->GetDiscipline("Psi-surge");
+            if (d)
+                d->Active = true;
         }
+        UpdateData();
     }
 }
+
+void FightWindow::CombatSkillLinkSlot(QString)
+{
+    CombatSkillWindow* dlg = new CombatSkillWindow(this, m_Player, m_Enemy);
+    dlg->exec();
+}
