@@ -2,12 +2,13 @@
 #define RULESWINDOW_H
 
 #include <QMainWindow>
+#include "controls/dialogwindow.h"
 
 namespace Ui {
     class RulesWindow;
 }
 
-class RulesWindow : public QMainWindow
+class RulesWindow : public DialogWindow
 {
     Q_OBJECT
 
