@@ -3,12 +3,12 @@
 
 #include <QDialog>
 #include <QSettings>
-
+#include "controls/dialogwindow.h"
 namespace Ui {
     class SettingsWindow;
 }
 
-class SettingsWindow : public QDialog
+class SettingsWindow : public DialogWindow
 {
     Q_OBJECT
 
