@@ -34,6 +34,7 @@ StatusWindow::StatusWindow(QWidget *parent, Player* player, Section* section, QS
     ui->lblSectionItems->setPalette(secondaryPalette);
     ui->lblStatus->setPalette(secondaryPalette);
     ui->lblDisciplines->setPalette(secondaryPalette);
+    ui->lblWeaponChecklist->setPalette(secondaryPalette);
     ui->lblRank->setPalette(secondaryPalette);
     ui->lblWeapons->setPalette(secondaryPalette);
     ui->lblItems->setPalette(secondaryPalette);
@@ -695,6 +696,7 @@ void StatusWindow::DiscipleLinkSlot(QString link)
     RulesWindow* dlg = new RulesWindow(this, m_Book->BaseDirectory);
     dlg->show();
     dlg->ScrollToAnchor(link);
+    dlg->exec();
 }
 
 void StatusWindow::CombatSkillLinkSlot(QString)
@@ -706,7 +708,11 @@ void StatusWindow::CombatSkillLinkSlot(QString)
 void StatusWindow::EditNotesSlot()
 {
     NotesWindow* dlg = new NotesWindow(this, m_Player);
-    dlg->exec();
+    connect(dlg, SIGNAL(destroyed()), this, SLOT(EditNotesClosedSlot()));
+    dlg->show();
+}
 
+void StatusWindow::EditNotesClosedSlot()
+{
     ui->lblNotes->setText(m_Player->GetNotes());
 }
